import { SummarizationOptions } from '../types/models.js';
/**
 * Formats for different model providers
 */
export type PromptFormat = 'anthropic' | 'openai' | 'gemini';
/**
 * Base interface for all prompt types
 */
interface BasePrompt {
    format: PromptFormat;
}
/**
 * Anthropic-style single string prompt
 */
interface AnthropicPrompt extends BasePrompt {
    format: 'anthropic';
    prompt: string;
}
/**
 * OpenAI-style chat messages
 */
interface OpenAIPrompt extends BasePrompt {
    format: 'openai';
    messages: Array<{
        role: 'system' | 'user' | 'assistant';
        content: string;
    }>;
}
/**
 * Gemini-style chat messages
 */
interface GeminiPrompt extends BasePrompt {
    format: 'gemini';
    messages: Array<{
        role: 'user' | 'model';
        parts: Array<{
            text: string;
        }>;
    }>;
}
export type ModelPrompt = AnthropicPrompt | OpenAIPrompt | GeminiPrompt;
/**
 * Main function to construct prompts for any model type
 */
export declare function constructPrompt(format: PromptFormat, content: string, type: string, options?: SummarizationOptions): ModelPrompt;
export {};
